<?php
namespace PortalPeople\DisabledPostcodes\Model\ResourceModel\DisabledPostcode;

use Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection;
use PortalPeople\DisabledPostcodes\Model\DisabledPostcode as Model;
use PortalPeople\DisabledPostcodes\Model\ResourceModel\DisabledPostcode as ResourceModel;

class Collection extends AbstractCollection
{
    protected function _construct(): void
    {
        $this->_init(Model::class, ResourceModel::class);
    }
}
