<?php
namespace PortalPeople\DisabledPostcodes\Model\ResourceModel;

use Magento\Framework\Model\ResourceModel\Db\AbstractDb;

class DisabledPostcode extends AbstractDb
{
    protected function _construct(): void
    {
        $this->_init('portalpeople_disabled_postcode', 'entity_id');
    }
}
