var config = {
    deps: [
        'PortalPeople_DisabledPostcodes/js/postcode-checkout-watch'
    ],
    config: {
        mixins: {
            'Magento_Checkout/js/model/error-processor': {
                'PortalPeople_DisabledPostcodes/js/model/error-processor-mixin': true
            }
        }
    }
};
