<?php
namespace PortalPeople\DisabledPostcodes\Model;

use Magento\Framework\Model\AbstractModel;

class DisabledPostcode extends AbstractModel
{
    protected function _construct(): void
    {
        $this->_init(\PortalPeople\DisabledPostcodes\Model\ResourceModel\DisabledPostcode::class);
    }
}
