<?php
namespace PortalPeople\DisabledPostcodes\Controller\Adminhtml\Postcode;

use Magento\Backend\App\Action;

abstract class AbstractPostcode extends Action
{
    public const ADMIN_RESOURCE = 'PortalPeople_DisabledPostcodes::manage';
}
