<?php
namespace PortalPeople\DisabledPostcodes\Controller\Adminhtml\Postcode;

use Magento\Framework\Controller\ResultFactory;

class Index extends AbstractPostcode
{
    public function execute()
    {
        $resultPage = $this->resultFactory->create(ResultFactory::TYPE_PAGE);
        $resultPage->setActiveMenu('PortalPeople_DisabledPostcodes::manage');
        $resultPage->getConfig()->getTitle()->prepend(__('Disabled Postcodes'));
        return $resultPage;
    }
}
