<?php
namespace PortalPeople\DisabledPostcodes\Controller\Adminhtml\Postcode;

use Magento\Framework\Controller\ResultFactory;

class Edit extends AbstractPostcode
{
    public function execute()
    {
        $resultPage = $this->resultFactory->create(ResultFactory::TYPE_PAGE);
        $resultPage->setActiveMenu('PortalPeople_DisabledPostcodes::manage');

        $id = (int)$this->getRequest()->getParam('id');
        $title = $id ? __('Edit Disabled Postcode Rule') : __('New Disabled Postcode Rule');
        $resultPage->getConfig()->getTitle()->prepend($title);

        return $resultPage;
    }
}
