body.portalpeople-postcode-blocked .checkout-shipping-method .action.continue,
body.portalpeople-postcode-blocked .button.action.continue.primary,
body.portalpeople-postcode-blocked button[data-role="opc-continue"] {
    display: none !important;
}

body.portalpeople-postcode-blocked .fieldset.shipping-information,
body.portalpeople-postcode-blocked .delivery-information {
    display: none !important;
}

.portalpeople-postcode-error {
    display: block !important;
    margin-top: 8px;
    color: #c9190b;
    font-size: 1.3rem;
    line-height: 1.4;
}

.portalpeople-postcode-error-checkout {
    margin-bottom: 12px;
}