<?php
namespace PortalPeople\DisabledPostcodes\Controller\Adminhtml\Postcode;

class NewAction extends AbstractPostcode
{
    public function execute()
    {
        return $this->_forward('edit');
    }
}
